/*
 *  Copyright (c) xlightweb.org, 2008. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Please refer to the LGPL license at: http://www.gnu.org/copyleft/lesser.txt
 * The latest copy of this software may be found on http://www.xlightweb.org/
 */
package org.xlightweb;

import java.io.IOException;

import org.xsocket.Execution;




/**
 * Listener, which will be call if the body is complete received. Example:
 * 
 * <pre>
 * class JsonRequestLogInterceptor implements IHttpRequestHandler {
 * 
 *    // will be called if request header is received (Default-InvokeOn is HEADER_RECEIVED)
 *    public void onRequest(IHttpExchange exchange) throws IOException {
 *    
 *       final IHttpRequest request = exchange.getRequest();
 *       
 *       // log message body only if content type is "application/json"
 *       if (request.hasBody() && request.getContentType().equals("application/json")) {
 *      
 *          IBodyCompleteListener cl = new IBodyCompleteListener() {
 *          
 *             public void onComplete() throws IOException {
 *                System.out.println(request); 
 *                exchange.forward(request);
 *             }
 *          };
 *          
 *          request.getNonBlockingBody().addCompleteListener(cl);
 *          
 *       } else {
 *          System.out.println(request.getRequestHeader());
 *          exchange.forward(request);
 *       }
 *    }
 * }	
 * 
 *  
 * 
 * </pre>
 * 
 * 
 * @author grro@xlightweb.org
 */
public interface IBodyCompleteListener {
	
	
	public static final int DEFAULT_EXECUTION_MODE = Execution.MULTITHREADED;
	
	
	/**
	 * call back if the artifact is complete received
	 * 
	 * @throws IOException if an exception occurs
	 */
	void onComplete() throws IOException;	
}
