/*
 *  Copyright (c) xlightweb.org, 2008. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Please refer to the LGPL license at: http://www.gnu.org/copyleft/lesser.txt
 * The latest copy of this software may be found on http://www.xlightweb.org/
 */
package org.xlightweb;


import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;




/**
 * simple message body parser
 *  
 * @author grro@xlightweb.org
 */
final class SimpleMessageBodyParser extends AbstractBodyParser {

	private static final Logger LOG = Logger.getLogger(SimpleMessageBodyParser.class.getName());
	
	private int received;
	
	
	/**
	 * constructor 
	 * 
	 * @param httpConnection   the http connection
	 * @param header           the header
	 * @throws IOException if an exception occurs
	 */
	public SimpleMessageBodyParser(AbstractHttpConnection httpConnection, IHttpHeader header) throws IOException {
		super(httpConnection, header);
	}

	

	/**
	 * {@inheritDoc}
	 */
	@Override
	void doParse(ComposedByteBuffer rawData) throws IOException {
		
		int read = rawData.drain(this);
		received += read;
			
		if (LOG.isLoggable(Level.FINE)) {
			LOG.fine("[" + getConnectionId() + "] received data (total received = " + received + " bytes)");
		}	
	}
	
	
    
    /**
     * {@inheritDoc}
     */
    @Override
    void onException(IOException ioe, ComposedByteBuffer rawData) {
        if (LOG.isLoggable(Level.FINE)) {
            LOG.fine("error occured by parsing simple message " + ioe.toString());
        }
    }
    
 

	/**
	 * {@inheritDoc}
	 */
	@Override
	void onDisconnect() {
		setComplete();
		super.onDisconnect();
	}
}

 